@@ -1,4 +1,4 @@
-use super::{remove_dirs, status_from_dirs, BuildStatus, BuildTool, BuildToolProbe};
+use super::{remove_dirs, status_from_dirs, BuildStatus, BuildTool, BuildToolKind, BuildToolProbe};
 use crate::build_tool_manager::BuildToolManager;
 
 use serde::Deserialize;
@@ -7,7 +7,6 @@ use std::{
     path::{Path, PathBuf},
 };
 
-
 pub fn register(manager: &mut BuildToolManager) {
     let probe = Box::new(CargoProbe {});
     manager.register(probe);
@@ -17,30 +16,29 @@ pub fn register(manager: &mut BuildToolManager) {
 pub struct CargoProbe;
 
 impl BuildToolProbe for CargoProbe {
-    fn probe(&self, path: &Path) -> Option<Box<dyn BuildTool>> {
-        if path.join("Cargo.toml").is_file() {
-            Some(Box::new(Cargo::new(path)))
+    fn probe(&self, dir: &Path) -> Option<Box<dyn BuildTool>> {
+        if dir.join("Cargo.toml").is_file() {
+            Some(Box::new(Cargo::new(dir)))
         } else {
             None
         }
     }
 
-    fn applies_to(&self, name: &str) -> bool {
-        // `name` should already be lowercase, but let's be defensive
-        let name = name.to_lowercase();
-        ["cargo", "rust", "rs"].contains(&name.as_str())
+    fn applies_to(&self, kind: BuildToolKind) -> bool {
+        use BuildToolKind::*;
+        matches!(kind, Cargo | Rust | Rs)
     }
 }
 
 #[derive(Debug)]
 pub struct Cargo {
-    path: PathBuf,
+    dir: PathBuf,
 }
 
 impl Cargo {
-    fn new(path: &Path) -> Self {
+    fn new(dir: &Path) -> Self {
         Self {
-            path: path.to_owned(),
+            dir: dir.to_owned(),
         }
     }
 }
@@ -55,15 +53,15 @@ impl BuildTool for Cargo {
         // the same effect, and also works in case Cargo is not installed on the
         // system.
 
-        remove_dirs(&self.path, EPHEMERAL_DIRS, dry_run)
+        remove_dirs(&self.dir, EPHEMERAL_DIRS, dry_run)
     }
 
     fn status(&self) -> anyhow::Result<BuildStatus> {
-        status_from_dirs(&self.path, EPHEMERAL_DIRS)
+        status_from_dirs(&self.dir, EPHEMERAL_DIRS)
     }
 
     fn project_name(&self) -> Option<anyhow::Result<String>> {
-        let toml_path = self.path.join("Cargo.toml");
+        let toml_path = self.dir.join("Cargo.toml");
         Some(read_project_name_from_cargo_toml(&toml_path))
     }
 }
