@@ -1,9 +1,6 @@
-use super::{remove_dirs, status_from_dirs, BuildStatus, BuildTool, BuildToolProbe};
+use super::{remove_dirs, status_from_dirs, BuildStatus, BuildTool, BuildToolKind, BuildToolProbe};
 use crate::build_tool_manager::BuildToolManager;
-use std::{
-    path::{Path, PathBuf},
-};
-
+use std::path::{Path, PathBuf};
 
 pub fn register(manager: &mut BuildToolManager) {
     let probe = Box::new(MixProbe {});
@@ -14,30 +11,29 @@ pub fn register(manager: &mut BuildToolManager) {
 pub struct MixProbe;
 
 impl BuildToolProbe for MixProbe {
-    fn probe(&self, path: &Path) -> Option<Box<dyn BuildTool>> {
-        if path.join("mix.exs").is_file() {
-            Some(Box::new(Mix::new(path)))
+    fn probe(&self, dir: &Path) -> Option<Box<dyn BuildTool>> {
+        if dir.join("mix.exs").is_file() {
+            Some(Box::new(Mix::new(dir)))
         } else {
             None
         }
     }
 
-    fn applies_to(&self, name: &str) -> bool {
-        // `name` should already be lowercase, but let's be defensive
-        let name = name.to_lowercase();
-        ["mix", "elixir", "ex", "exs"].contains(&name.as_str())
+    fn applies_to(&self, kind: BuildToolKind) -> bool {
+        use BuildToolKind::*;
+        matches!(kind, Mix | Elixir | Ex | Exs)
     }
 }
 
 #[derive(Debug)]
 pub struct Mix {
-    path: PathBuf,
+    dir: PathBuf,
 }
 
 impl Mix {
     fn new(path: &Path) -> Self {
         Self {
-            path: path.to_owned(),
+            dir: path.to_owned(),
         }
     }
 }
@@ -55,11 +51,11 @@ impl BuildTool for Mix {
         // works just as well (better?), is faster, and doesn't require mix to
         // be installed.
 
-        remove_dirs(&self.path, EPHEMERAL_DIRS, dry_run)
+        remove_dirs(&self.dir, EPHEMERAL_DIRS, dry_run)
     }
 
     fn status(&self) -> anyhow::Result<BuildStatus> {
-        status_from_dirs(&self.path, EPHEMERAL_DIRS)
+        status_from_dirs(&self.dir, EPHEMERAL_DIRS)
     }
 
     fn project_name(&self) -> Option<anyhow::Result<String>> {
