@@ -1,8 +1,6 @@
-use super::{remove_dirs, status_from_dirs, BuildStatus, BuildTool, BuildToolProbe};
-use crate::{build_tool_manager::BuildToolManager};
-use std::{
-    path::{Path, PathBuf},
-};
+use super::{remove_dirs, status_from_dirs, BuildStatus, BuildTool, BuildToolKind, BuildToolProbe};
+use crate::build_tool_manager::BuildToolManager;
+use std::path::{Path, PathBuf};
 
 pub fn register(manager: &mut BuildToolManager) {
     let probe = Box::new(NpmProbe {});
@@ -13,26 +11,24 @@ pub fn register(manager: &mut BuildToolManager) {
 pub struct NpmProbe;
 
 impl BuildToolProbe for NpmProbe {
-    fn probe(&self, path: &Path) -> Option<Box<dyn BuildTool>> {
-        if path.join("package.json").is_file() {
+    fn probe(&self, dir: &Path) -> Option<Box<dyn BuildTool>> {
+        if dir.join("package.json").is_file() {
             Some(Box::new(Npm {
-                path: path.to_owned(),
+                dir: dir.to_owned(),
             }))
         } else {
             None
         }
     }
 
-    fn applies_to(&self, name: &str) -> bool {
-        // `name` should already be lowercase, but let's be defensive
-        let name = name.to_lowercase();
-        name == "npm"
+    fn applies_to(&self, kind: BuildToolKind) -> bool {
+        kind == BuildToolKind::Npm
     }
 }
 
 #[derive(Debug)]
 pub struct Npm {
-    path: PathBuf,
+    dir: PathBuf,
 }
 
 static EPHEMERAL_DIRS: &[&str] = &["node_modules"];
@@ -40,11 +36,11 @@ static EPHEMERAL_DIRS: &[&str] = &["node_modules"];
 impl BuildTool for Npm {
     fn clean_project(&mut self, dry_run: bool) -> anyhow::Result<()> {
         // TODO: also delete build directory, depending on the language(s) used
-        remove_dirs(&self.path, EPHEMERAL_DIRS, dry_run)
+        remove_dirs(&self.dir, EPHEMERAL_DIRS, dry_run)
     }
 
     fn status(&self) -> anyhow::Result<BuildStatus> {
-        status_from_dirs(&self.path, EPHEMERAL_DIRS)
+        status_from_dirs(&self.dir, EPHEMERAL_DIRS)
     }
 }
 
